#
# spec file for package delve
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define shortname dlv

Name:           delve
Version:        1.24.1
Release:        1.1
Summary:        Debugger for the Go Programming Language
License:        MIT
Group:          Development/Languages/Go
URL:            https://github.com/go-delve/delve
Source:         %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  golang(API) >= 1.17
# your_linux_architecture_is_not_supported_by_delve (support_sentinel_linux.go)
ExcludeArch:    s390x ppc64 ppc64le %arm riscv64

%description
Delve is a debugger for the Go programming language. The goal of
the project is to provide a simple, full featured debugging tool
for Go. Delve should be easy to invoke and easy to use. Chances are
if you're using a debugger, things aren't going your way. With that
in mind, Delve should stay out of your way as much as possible.

%prep
%autosetup -a 1

%build
%ifnarch ppc64
export GOFLAGS="-buildmode=pie"
%endif
go build \
   ./cmd/%{shortname}

%check
# execute the binary as a basic check
./%{shortname} --help

%install
install -D -m 0755 %{shortname} "%{buildroot}/%{_bindir}/%{shortname}"

%files
%doc README.md
%doc Documentation
%license LICENSE
%{_bindir}/%{shortname}

%changelog
* Thu Mar  6 2025 Jeff Kowalczyk <jkowalczyk@suse.com>
- Update to version 1.24.1:
  * *: v1.24.1 (#3931)
  * proc: expose breakpoint hitcounts in expressions (#3874)
  * proc: do not pin function call returns for toplevel call (#3925)
  * telemetry: add stack counter for internal errors (#3930)
  * service/test: handle wider registers in test (#3929)
  * dwarf,proc: various fixes to support DWARFv5 (#3893)
  * pkg/proc: support watchpoint on nil interface (#3924)
  * pkg/proc: add support for interface watchpoints (#3922)
  * proc/gdbserial: use rr version to determine style of qRRCmd (#3921)
  * logflags: replace logrus with log/slog (#3918)
  * *: remove uses of reflect.MethodByName from all of Delve (#3916)
  * CirrusCI: update FreeBSD version (#3917)
  * proc: some refactorings for supporting struct literals (#3909)
  * proc: better error message for breakpoints on stripped binaries (#3914)
  * TeamCity: remove riscv64 from configuration (#3912)
  * proc: allow access to thread registers after a function call (#3908)
  * *: add support for linux/loong64 to native backend (#3892)
  * service/dap: provide process events after launch (#3902)
  * pkg/terminal: support zed editor and allow args in DELVE_EDITOR (#3899)
  * proc: switch to goroutine stack if we make no progress on thread stack (#3898)
  * proc: remove irrelevant TODO comment (#3891)
  * pkg: refactor sort.Sort to slices.SortFunc (#3880)
  * delete redundancy code. (#3897)
  * pkg/proc/internal/ebpf: Fix uprobe address (#3894)
  * service/test: disable TestGuessSubstitutePath on TeamCity/linux/tip (#3890)
  * proc: remove leftover fmt.Printf (#3885)
  * fix check it.Err() != nil but return a nil value error err (#3886)
- Packaging improvements:
  * Update to BuildRequires: golang(API) >= 1.21 matching go.mod
* Wed Dec 18 2024 Jeff Kowalczyk <jkowalczyk@suse.com>
- Update to version 1.24.0:
  * *: v1.24.0 (#3883)
  * goversion,proc_test: add go1.24 compatiblity, disable broken test (#3882)
  * proc: fix loading goroutine labels on Go 1.24 (#3879)
  * service/rpc1: delete APIv1 (#3881)
  * tests: removing of dlvbin is not needed (#3875)
  * pkg/proc: support swiss table map implementation (#3838)
  * terminal/starbind: allow modification of structs returned by API (#3872)
  * pkg/proc,service/debugger: do not disable unsatisfiable breakpoints (#3868)
  * proc: allow accessing captured variable as if they were struct fields (#3866)
  * feat: print a message when the debuggee process exits (#3870)
  * proc: fix issue on Windows when launching process while detached (#3867)
  * proc/core/minidump: remove newlines from minidump logs (#3869)
  * pkg/proc/native,pkg/proc/amd64util: xsave decoding cleanup (#3840)
  * go.mod: sync golang.org/x/telemetry@58a1122356f5 (#3857)
  * all: remove redundant err declarations (#3855)
  * tests: calling os.Exit in TestMain is not required (#3856)
  * proc: do not ignore error return of funcCallEvalFuncExpr (#3850)
  * Documentation: using `go install` is preferable (#3853)
  * proc: fix typos in errors and comments (#3852)
  * proc: run gofmt (#3851)
  * proc: fix rangeFuncStackTrace with inlined functions (#3849)
  * service,terminal,cmd/dlv: automatically guessing substitute-path config (#3781)
  * service/rpc2: correct ExamineMemory length error message (#3846)
  * all: import go telemetry and enable crash reporting (#3841)
  * TeamCity: move riscv64 backend testing to tip (#3842)
  * _scripts: update staticcheck version (#3839)
  * proc: use CPUID to determine ZMM_Hi256 region offset (#3831)
  * Documentation: fix autogenerated markdown documentation (#3836)
  * goversion: parse version for development builds (#3837)
  * pkg/proc/core: Clean up some repetitive code (#3834)
  * *: mark riscv64 port as experimental (#3835)
  * delve: add linux-riscv64 support (#3785)
  * all: update golang.org/x/arch to v0.11.0 (#3826)
  * proc: adds pointer pinning to call injection (#3787)
  * terminal,service: add raw examinemem dump (#3721)
  * tests: disable TestGeneratedDoc on 1.24 (tip) (#3820)
  * *: replace uses of uniq with slices.Compact (#3821)
  * pkg/proc: simplify tests by using errors.As (#3818)
  * cmds/commands: Update 'client-addr' to support Unix domain sockets (#3819)
  * Documentation: Add dape to list of plugins (#3817)
  * proc: step into coroutine (#3791)
* Mon Sep 23 2024 Jeff Kowalczyk <jkowalczyk@suse.com>
- Update to version 1.23.1:
  * *: release version 1.23.1 (#3816)
  * proc: cache module data (#3800)
  * proc: for optimized functions allow .closureptr to not exist (#3808)
  * proc: improve Rosetta check (#3810)
  * proc: fix result type of division of untyped constants (#3794)
  * service/dap: fix test failure with 1.24 (#3805)
  * service/dap: make handlesMap generic (#3798)
  * proc: workaround for macOS section name truncation (#3799)
  * terminal/starbind: fix starlark conversion of named consts (#3802)
  * chore: fix function name (#3803)
  * eval: Allow reslicing a slice up to its cap, rather than its length (#3796)
  * proc: fix TestRangeOverFuncNext on linux/386 (#3795)
  * proc: fix step stuttering when entering range-over-func bodies (#3788)
  * proc: move stepping test to their own file (#3784)
* Tue Jul 16 2024 Jeff Kowalczyk <jkowalczyk@suse.com>
- Update to version 1.23.0:
  * *: release version 1.23.0 (#3782)
  * teamcity: fix typo in configuration (#3783)
  * goversion: add 1.23 to supported versions, update test matrix (#3780)
  * proc: fix bug with range-over-func stepping (#3778)
  * *: replace old golang.org links with new go.dev (#3774)
  * service/rpc1: add Go Reference doc (#3779)
  * proc: use .closureptr for stepping through range-over-func statements (#3763)
  * pkg/dwarf/line: use t.Logf instead of fmt.Printf in tests (#3772)
  * pkg: refactor to buf.WriteString() (#3769)
  * pkg/terminal: add missing file.Close() call (#3770)
  * go.mod: update gopkg.in/yaml to v3 (#3776)
  * pkg/proc: fix 404 links and change to https (#3775)
  * *: remove redundant lines at the start/end of block (#3773)
  * fix: LoadAbstractOriginAndSpecification infinite loop caused by abstract origin point to itself. (#3767)
  * service/debugger: evaluate breakpoint vars on g-less threads (#3759)
  * proc: support stepping through range-over-func statements with inlining (#3755)
  * fix: mem cache out of range panic caused by overflow (#3761)
  * pkg/proc,service/debugger: fix debuginfod-find source (#3762)
  * refactor: move loadModuleData from runtimeTypeToDIE and expose the apis (#3741)
  * all: fix typos in docs, comments and package name (#3757)
  * pkg/terminal: do not use deprecated strings.Title (#3756)
  * proc: initial support for expressions with range-over-func (#3750)
  * *: replace fmt.Errorf with errors.New (#3752)
  * pkg/astutil,pkg/elfwriter: fix package doc (#3753)
  * service: print better message for unattended stops (#3747)
  * proc: refactor identifier evaluation for range-over-func support (#3738)
  * proc: fix TestRangeOverFuncNext (#3740)
  * proc: fix bug with stack watchpoints going out of scope (#3742)
  * pkg/terminal,service/debugger: Support to add a new suboption --follow-calls to trace subcommand  (#3594)
  * cmd/dlv: print out message with stack trace when breakpoint is hit but has no waiting client (#3632)
  * proc: initial stepping with range-over-func support (#3736)
  * proc/gdbserial: add environment variables to configure rr invocation (#3726)
  * *: update actions/checkout to v4 (#3731)
  * *: remove redundant lines at the start/end of block (#3730)
  * pkg/terminal: remove deprecated starlark global options (#3722)
  * gdbserial: fixes for rr 5.7.0 (#3718)
  * gdbserial: update path of lldb protocol extension documentation (#3727)
  * pkg/proc/gdbserial: optimize gdbwire backend (#3715)
  * _scripts: upgrade to python3 (#3716)
  * pkg/proc: fix watchpoints on macos (#3703)
  * pkg/terminal: Add function name to return tracepoints (#3712)
  * rr: fix gdb parsing (#3705)
  * proc: generalize escapeCheck and allocString (#3687)
  * cmd/dlv: improve positional argument completion (#3699)
  * pkg/terminal: remove duplicated word (#3707)
  * pkg/terminal: clear erroneous name setting on postfix if (#3702)
  * tests: fix tests on Go 1.23 (#3697)
  * cmd/dlv: fix panic on connect fail (#3698)
  * cmd/dlv: add shell (non-)completions to flags taking args (#3696)
  * proc: change 'step' command so that it steps through go statements (#3686)
  * pkg/terminal: allow postfix if for breakpoint conds (#3693)
  * proc: support reading captured variables of closures (#3682)
  * pkg/proc: defend better against missing DWARF (#3695)
  * proc,go.mod: update x/sys remove KeepAlive calls (#3680)
  * proc: catch panics when reading debug info for stripped executables (#3678)
  * dwarf/loclist: remove impossible condition (#3677)
  * Cirrus-CI: update to FreeBSD 13.3 (#3679)
  * proc/evalop: remove no longer needed old Go files (#3676)
  * pkg/terminal: print breakpoint number on stop (#3675)
  * pkg/terminal,pkg/proc: Implement next-instruction (#3671)
  * *: Upgrade github.com/google/go-dap (#3673)
  * elfwriter: add WriteSectionHeaders (#3666)
  * *: misc fixes for go1.23 (#3663)
  * dwarfbuilder: fix makeAbbrevTable (#3665)
* Wed Mar  6 2024 Jeff Kowalczyk <jkowalczyk@suse.com>
- Update to version 1.22.1:
  * *: release version 1.22.1 (#3662)
  * pkg/proc: remove usage of gore dependency (#3664)
  * cmd/dlv: fix --continue with unix domain sockets (#3658)
  * Don't use a fixed width for s when parsing /proc/net/tcp lines (#3660)
  * *: update gore (#3659)
  * terminal: add prompt color option (#3648)
  * terminal: add color highlighting to stacktraces (#3649)
  * cmd/dlv: support unix domain sockets (#3655)
  * service/dap: support waitfor option for 'dap attach' only (#3656)
  * *: update go-delve/gore (#3646)
  * *: remove accidentally committed binary (#3645)
  * proc: if a reslice operator is used load the whole slice (#3623)
  * proc/gdbserver: clean up rr directory on detach (#3570)
  * proc: skip TestDebugStripped on development versions of Go (#3642)
  * evalop: fix name of executeOp function in test (#3643)
  * service/dap: make TestEvaluateCallFunction independent of line numbers (#3644)
  * proc/native: add support sentinel for FreeBSD with cgo disabled (#3636)
  * make.go: do not recodesign when rebuilding (#3639)
  * proc/native: remove dead code in nonative_darwin.go (#3637)
  * proc: fix stacktrace frame after runtime.sigpanic (#3638)
  * proc: fix dynamic library loading with musl loader (#3621)
  * proc: fix TestCondBreakpointWithFrame flakes on 1.22rc1 (#3624)
  * terminal: add paging to print, vars, args and locals (#3620)
  * TeamCity: speed up ppc64le CI (#3622)
  * Documentation: document runtime.frame(n).varname (#3625)
  * go.mod: Update version of go-delve/liner (#3619)
  * Cirrus-CI: update FreeBSD version (#3618)
* Fri Dec 29 2023 Jeff Kowalczyk <jkowalczyk@suse.com>
- Update to version 1.22.0:
  * *: release version 1.22.0 (#3606)
  * *: Update gore dep for 1.22 (#3611)
  * proc: fix TestPackageRenames on go1.22 on linux/386 (#3610)
  * service/dap: fix close on closed channel (#3609)
  * goversion: include pre-releases in VersionAfterOrEqual check (#3607)
  * proc: fix ppc64 arch name check (#3608)
  * teamcity,version: add 1.22 to supported versions and CI matrix (#3601)
  * proc: make some type casts less counterintuitive
  * *: Use forked goretk/gore module (#3597)
  * Show pprof labels in thread names (#3501)
  * service/dap: fix close on closed channel panic (#3573)
  * add all branches but PRs to filter (#3590)
  * all: run go mod tidy (#3589)
  * tests: fix tests in go1.22 (#3583)
  * proc: skip trapthread for harcoded breakpoints after manual stop (#3582)
  * proc: fix TestIssue1101 flake (#3585)
  * update TeamCity DSL version to 2023.05 and remove tip configurations from Aggregator (#3581)
  * add missing import in TeamCity DSL (#3580)
  * pkg/proc: use gore to obtain info from stripped binaries (#3577)
  * CI: update teamcity settings (#3579)
  * pkg,service/dap: use switch instead of ifs (#3576)
  * CI: Extract tip builds into a separate sub-project (#3578)
  * proc/gdbserial: refactor parsing of key-value pairs from gdb protocol (#3574)
  * proc: simplify and generalize runtime.mallocgc workaround (#3571)
  * TeamCity: remove windows/arm64 builders from chain (#3572)
  * service: fix typo in variable name (#3575)
  * terminal: clear substitute path rules cache when config is used (#3567)
  * *: remove checks for TRAVIS env variable (#3568)
  * pkg,service: remove unnecessary convertions (#3564)
  * chore: use strings.Contains instead (#3562)
  * pkg/proc: unskip passing tests and reorganize (#3561)
  * pkg/proc: improve support unwinding from sigpanic (#3559)
  * TeamCity: reupgrade linux/386 builder to Go 1.21 (#3560)
  * Shorten variable types (#3535)
  * pkg,service: Remove redundant build constraints (#3556)
  * *: Correct spelling mistakes (#3555)
  * service: fix a bunch of linter warnings from GoLand (#3551)
  * *: update dependencies (#3552)
  * proc: add regression test for issue #3548 (#3553)
  * cmd: fix a bunch of linter warnings from GoLand (#3550)
  * pkg/proc: add inline function support for stripped binaries (#3549)
  * proc/native: wherever we check for exited we should also check detached (#3547)
  * *: release 1.21.2 (#3546)
  * proc,service/dap,proc/gdbserial: fixes for debugserver --unmask-signals (#3541)
  * *: Add explicit code of conduct (#3540)
  * proc: allow evaluator to reference previous frames (#3534)
  * service/api: use bitfield for prettyprint flags (#3536)
  * proc: remove expr evaluation goroutine from EvalExpressionWithCalls (#3532)
  * CI: update staticcheck version (#3533)
  * proc: add min and max builtins (#3530)
  * proc: fix comment typos (#3531)
  * proc: use stack machine to evaluate expressions (#3508)
* Mon Oct 30 2023 Jeff Kowalczyk <jkowalczyk@suse.com>
- Packaging improvements:
  * Re-enable binary stripping and debuginfo boo#1210938
  * Update to BuildRequires: golang(API) >= 1.17 matching go.mod
  * Build PIE with pattern that may become recommended procedure:
    %%%%ifnarch ppc64 GOFLAGS="-buildmode=pie" %%%%endif go build
    A go toolchain buildmode default config would be preferable
    but none exist at this time.
  * Drop mod=vendor, go1.14+ will detect vendor dir and auto-enable
  * Drop go build -o arg, default binary name is pkg of main()
  * Drop comment about upstream Makefile static build options fail
  * Add basic %%check to execute binary --help
* Mon Oct 30 2023 Jeff Kowalczyk <jkowalczyk@suse.com>
- Update to version 1.21.2:
  * *: release 1.21.2 (#3543)
  * proc: use DW_AT_trampoline to detect auto-generated code (#3528)
  * proc/native: use cgo instead of C for freebsd (#3529)
  * service/test: disable TestClientServer_chanGoroutines with rr backend (#3492)
  * proc: implement follow exec mode on Windows (#3507)
  * Use a valid timezone in tested binary (#3527)
  * pkg/terminal: support vscode in edit command (#3524)
  * service/dap: fix bugs in stdout/stderr handling (#3522)
  * service/dap: add the concrete type to interface type (#3510)
  * all: remove obsolete build tags "// +build" (#3513)
* Mon Oct 30 2023 Jeff Kowalczyk <jkowalczyk@suse.com>
- Update to version 1.21.1:
  * V1.21.1 (#3518)
  * all: replace deprecated io/ioutil with io and os (#3509)
  * pkg/proc: macho: Enable debugging stripped binaries (#3511)
  * fix memory leak (#3512)
  * pky/proc: enable function call injection in Delve for linux/ppc64le (#3449)
  * pkg/terminal: support more editors with edit command (#3506)
  * proc: move StepInstruction method to TargetGroup (#3488)
  * Various fixes for go 1.22 (#3455)
  * service/dap: accept a string list as launch request's buildFlags (#3496)
  * _scripts: remove unnecessary os.ExpandEnv (#3504)
  * proc,service: simplify tests with T.Setenv (#3503)
  * pkg/terminal: add 'packages' command (#3499)
  * pkg/proc/internal/ebpf: remove redundant nil check (#3502)
  * service/dap: strip package paths from symbols in callstack (#3500)
  * pkg/proc: Fix PIE tests on ppc64le port (#3498)
  * go.mod: update version of github.com/cilium/ebpf (#3491)
  * api,dap: fix hexadecimal printing of vars with symbolic const values (#3487)
  * pkg,service: fix typos in comments, exceptions, tests (#3486)
  * proc: refactorings to implement follow-exec mode on Windows (#3441)
  * proc,service,terminal: add ways to list goroutines waiting on a channel (#3481)
  * proc: disable "wait-for" tests on freebsd (#3482)
  * DWARF CFI: use a stack for restore/remember opcodes (#3480)
  * proc: remove unused functions (#3479)
  * cmd/dlv: handle ctrl-c during tracing (#3477)
  * teamcity: misc changes to CI (#3476)
  * proc: when stepping set condition on thread ID if there is no curg (#3475)
  * pkg/proc: add support for more types in ebpf tracing backend (#3474)
  * pkg,service: make receiver names consistent (#3473)
  * goversion: parse new version format and simplify version representation (#3470)
  * Update target.go (#3471)
  * *: remove deepsource.toml (#3468)
  * gobuild: pass user specified -C argument first (#3456)
  * locspec: fix SubstitutePath when converting a Windows path to Linux (#3453)
  * proc: fix stacktraces on freebsd/amd64/go1.20 (#3458)
  * proc: fix PIE support on macOS (#3467)
  * teamcity: hold back linux/386 builds to 1.20 (#3465)
  * service/dap: use == to test io.EOF (#3464)
  * goversion,teamcity: update test matrix and fix build scripts (#3463)
  * *: Fix ppc64le test runs (#3460)
  * Documentation,cmd/dlv: clean up command line usage help (#3395)
  * proc: add waitfor option to attach (#3445)
  * logflags: simplify Logger interface (#3274)
  * starbind: fix Starlark slice unmarshaling (#3454)
  * pkg/terminal: use reflect.Value.IsValid to check a zero Value (#3450)
  * proc: replace use of runtime.GOARCH with Arch.Name (#3442)
  * proc,ebpf: mark as unreadable args with unsupported types with ebpf (#3444)
  * service/api: in multiline mode print address of pointers (#3448)
  * terminal: restore breakpoints set with line offset on restart (#3425)
  * all: use "len == 0" rather than "len <= 0" when checking empty slice/string (#3439)
  * service/dap: fix typos in comments (#3438)
  * pkg/proc: simplify code with trivial changes (#3436)
  * *: add linux/ppc64le targets (#3435)
  * terminal,service: better printing of suspended breakpoints (#3415)
  * proc: check recursion level when loading pointers (#3431)
  * *: add ppc64le support (#2963)
  * service/dap: fix test for debug in progress (#3407)
  * all: fix typos (#3434)
  * pkg,service: refactor to use %%q instead of "%%s" (#3430)
  * pkg/dwarf/frame: fix FrameDescriptionEntries's Append (#3433)
  * pkg/proc,service/*: Supports sending output to clients when running programs remotely (#3253)
  * proc: read context from sigtrampgo, fixes TestCgoStacktrace2 on 1.21 (#3401)
* Tue Aug 29 2023 Dirk Müller <dmueller@suse.com>
- update summary and architecture excludes
* Wed Jun 28 2023 jkowalczyk@suse.com
- Update to version 1.21.0:
  * all: Bump to v1.21.0 (#3428)
  * proc: skip TestDebugStripped on linux/386/pie (#3427)
  * service/dap: fix typos in comments (#3426)
  * pkg/proc: improve stripped binary support with PIE (#3421)
  * proc: only print warning when gopclntab can not be read for first image (#3420)
  * service,terminal: when libraries don't have debug_info print reason (#3419)
  * pkg/terminal: regenerate starlark mappings (#3418)
  * pkg/proc: fix ebpf probe tracing backen uprobe handling (#3417)
  * pkg/proc: enable basic debug functionality for stripped ELF binaries (#3408)
  * terminal/starbind: add online help for starlark (#3388)
  * service/dap: update go-dap to latest (#3414)
  * TeamCity: fix linux/arm64 build (second attempt) (#3411)
  * terminal: expand ~ in paths passed to 'source' (#3387)
  * proc/test: reenable cgo testing on FreeBSD (#3394)
  * terminal: ask for confirmation when using 'quit -c' with breakpoints (#3398)
  * TeamCity: fix linux/arm64 build (#3403)
  * rpc2, debugger: Fix comments around goroutine grouping (#3374)
  * cmd/commands: Fix to read debug info file from the correct directory when using trace command with -e option. (#3405)
  * starbind: fix use of ptr variables in starlark  (#3386)
  * debugger: inline clearBreakpoint, createLogicalBreakpoint (#3389)
  * TeamCity: actually run linux/386 tests on linux/386 (#3392)
  * service/rpccommon: correct wrong comments (#3397)
  * docgen: fix links with trailing dots  (#3399)
  * dwarf: ignore DeclLine for function args (#3400)
  * _scripts: fix typos (#3402)
  * dwarf/op: use readMemory function (#3391)
  * starbind: Make the time module available to star scripts (#3375)
  * documentation: add a note about starlark structs (#3376)
  * debuginfod-find stderr may contain diagnostics; look at stdout only for filename (#3381)
  * dwarf,proc: fix typos in comments and error messages (#3379)
  * service: fix typos in comments, logs, tests, and vars (#3378)
  * proc: remove addrret field from Stackframe struct (#3373)
  * pkg/proc,pkg/terminal: close response body in tests (#3372)
  * cmd/dlv,service/dap: use randomized name as default output binary (#3366)
  * pkg/proc: pad variable mem in extractVarInfoFromEntry (#3365)
  * cmd/dlv: logger is not closed in connect command (#3367)
  * proc: fix runtime type handling for Go 1.21 (#3370)
  * proc,terminal: read command line of new processes (#3346)
  * trace: add timestamp to the output (#3358)
  * service/dap: refactor funcs always returning nil error (#3357)
  * dwarf/godwarf: fix alignment calculation for typedef types (#3362)
  * refactor: replace `Readdir(-1)` with `os.ReadDir` (#3361)
  * chore: don't ignore directory cmd/dlv (#3359)
  * pkg/proc: add missing response body Close in test (#3355)
  * pkg/proc: remove memlock limit for ebpf trace backend (#3353)
  * *: misc improvements to config command and substitute-path rules (#3335)
  * service/dap: use reloaded value
  * service/dap,service/debugger: refactor regexp funcs
  * proc/test: replace old func testName with T.Name
  * service: fix typos in comments (#3344)
  * Add additional information to how to filter goroutines
  * service/debugger,terminal: API and user interface for follow exec mode (#3286)
  * proc/native: support core dumping on FreeBSD (#3305)
  * debugger: do not panic if defer location can not be found (#3329)
  * proc: Simplify eBPF backend implementation (#3325)
  * proc: step breakpoints shouldn't hide normal breakpoints (#3287)
  * service/dap: fix failing test on Go 1.21 (#3312)
  * proc: disable flaky tests on windows/arm64 (#3328)
  * proc: fix match condition in TestGnuDebuglink
  * proc: fix test by adding missing assert
* Thu Apr  6 2023 jkowalczyk@suse.com
- Update to version 1.20.2:
  * proc: fix TestEvalExpression on Windows (#3313)
  * terminal: Fix printing boolean values in Starlark scripts (#3314)
  * proc: fix escapeCheck infinite recursion if something can not be (#3311)
  * proc: support multiple functions with the same name (#3297)
  * proc: fuzzing expression evaluator and variable loader (#3293)
  * proc: limit maximum time.Time we try to format (#3294)
  * Documentation: expand project layout to match usage (#3304)
  * proc: fix automatic breakpoints visibility (#3300)
  * proc,terminal: remove unused unexported functions (#3299)
  * cmd/dlv: Add flag to replay for rr onprocess pid (#3281)
  * proc: do not try to load a non-empty slice if the base address is 0 (#3295)
  * Documentation: fix typo and grammar issues (#3291)
  * dwarf/line: enable TestGrafana on Windows (#3289)
  * dwarf/op: change generated comment header (#3288)
  * proc,proc/native: adds ability to automatically debug child processes (#3165)
  * Default to stop test_windows.ps1 when there is an error (#3285)
  * dwarf/line: handle end_seq properly (#3277)
  * proc: remove unused parameter from resolveParametricType (#3276)
  * TeamCity,Documentation: use new TeamCity URL (#3275)
  * terminal/logflags: Added `SetLoggerFactory(LoggerFactory)` (#3257)
  * *: remove some code for Go 1.12 or earlier (#3271)
  * pkg/proc,service/test: refactor to strings.ReplaceAll (#3269)
  * _scripts: Update staticcheck (#3270)
  * proc/native: fix syscalls to SYS_PROCESS_VM_READV (and WRITEV) (#3273)
  * dwarf: fix broken external url to arm dwarf mapping (#3272)
  * Documentation: watch example for arbitrary address (#3268)
  * service/dap: correct typos in comments (#3264)
  * cmd/dlv: fix exit status for trace subcommand  (#3263)
  * godwarf: Allow extracting a DWARF entry's field (#3258)
  * _scripts: fix log.Printf format specifier (#3260)
  * cmd/dlv, pkg/proc: use T.TempDir in tests (#3256)
  * pkg/proc: do not check decl line for FunctionArguments (#3254)
  * terminal: use exact window size for pager (#3249)
  * proc/dwarf: Move util functions to dwarf package (#3252)
  * proc/dwarf: LEB128 encode/decode in separate pkg (#3235)
  * debugger,terminal: Allow setting and clearing breakpoints after process exit (#3246)
  * pkg/terminal: use default for Y/n empty response (#3248)
  * godwarf: Attempt to load `DW_AT_specification` if present (#3247)
  * terminal: Add config options for tab printing (#3243)
  * pkg/proc: fix stripping DYLD_INSERT_LIBRARIES on macOS (#3245)
  * cmd/dlv: match go test behavior when dlv test gets a list of .go files (#3232)
  * pkg/proc: populate pointer values (#3229)
  * pkg/terminal: fix handling list colors via config (#3240)
  * Documentation: document how to debug runtime with Delve (#3234)
  * go.mod: update github.com/google/go-dap to v0.7.0 (#3237)
  * pkg/proc: apply simplifycompositelit analysis fixes (#3236)
  * proc: Fix typos in the comments (#3231)
  * service/debugger: fix comment on EvalVariableInScope (#3225)
  * proc/native: fix FreeBSD backend (#3224)
  * TeamCity: fix windows/amd64 builds (#3223)
  * Documentation/faq: Correct commands in substitute-path section (#3222)
  * *: Change comments to match common Go standarts (#3221)
  * Update github.com/derekparker/trie dependency (#3219)
  * dwarf/frame: Remove expression constants (#3218)
  * proc: replace os.SEEK_CUR with io.SeekCurrent (#3214)
  * Documentation: add -test.run to test example (#3212)
- Packaging update source service mode to manual formerly disabled
* Tue Dec 13 2022 jkowalczyk@suse.com
- Update to version 1.20.1:
  * gdbserial: continue if tcsetpgrp fails (#3211)
* Thu Dec  8 2022 jkowalczyk@suse.com
- Update to version 1.20.0:
  * *: CHANGELOG and bump to version 1.20.0 (#3209)
  * Test windows/arm64 pipeline (#3200)
  * proc: extend macOS workaround to amd64 (#3204)
  * proc/gdbserver: set child process pgrp as foreground group (#3205)
  * *: early fixes for go1.20 (#3180)
  * Run CI tests on windows/arm64 agents (#3198)
  * cmd/dlv: Include hidden flag -c for coredumpctl support (#3195)
  * G struct offset is a pointer to an offset since go1.20 (#3196)
  * proc: prefer addresses when setting a breakpoint (#3193)
  * pkg/proc: fix arm64 linux cgo stacktrace (#3192)
  * Two fixes to type cast evaluation (#3186)
  * bininfo: Log when the file listed in .gnu_debuglink is not found (#3188)
  * service/debugger: allow setting a breakpoint with a specific ID (#3185)
  * proc/gdbserial/gdbserver: Don't pass DYLD_INSERT_LIBRARIES to debugserver (#3181)
  * proc: fix index access to already-loaded string values (#3184)
  * service/debugger: Assume current dir for exec (#3167)
  * pkg/terminal: Improve error when unable to read history file (#3169)
  * Add type to call evaluation and expression evaluation (#3172)
  * proc/native: acquire debug programs privilege on Windows (#3162)
  * pkg: fix a few function names on comments
  * service/dap: fix nil ptr deref when current addr is not in a func (#3157)
  * proc: disable TestCGONext on darwin/amd64 (#3160)
  * proc: remove import "C" for linux/386 backend (#3159)
  * proc,terminal: allow setting suspended breakpoints (#3154)
  * Documentation: add homebrew installation instructions back again
  * cmd/dlv: disable TestTraceMultipleGoroutines on FreeBSD (#3144)
  * proc: allow type casts between compatible types (#3149)
  * proc: remove old method to resolve the type of an interface to a DIE (#3150)
  * proc,service/debugger: track how breakpoints were originally set (#3148)
  * proc,service: change FindLocation to work with multiple targets (#3103)
  * service/dap: show full value when evaluating log messages (#3141)
  * proc,_scripts/rtype.go: add rtype annotations for g.atomicstatus (#3143)
  * proc: fix openSeparateDebugInfo backwards compatibility path (#3145)
  * proc: fix cast to empty interface type (#3146)
  * proc/native: fix support_sentinel_darwin.go name (#3147)
  * Add support for windows/arm64 (#3063)
  * service/debugger: merge attachErrorMessage, verifyBinaryFormat (#3142)
  * terminal: do not use WaitSince as unix time (#3139)
  * proc: fix hang caused by g.atomicstatus has change to atomic.Uint32 (#3129)
  * go.mod,proc: upgrade golang.org/x/sys/unix (#3134)
  * proc: reduntant type conversion (#3131)
  * terminal: remove leftover GOPATH references (#3117)
  * Add Debugger to UIs list in EditorIntegration (#3127)
  * Documentation: reverse step, next and stepout (#3119)
* Tue Aug 23 2022 jkowalczyk@suse.com
- Update to version 1.9.1:
  * v1.9.1 (#3116)
  * proc: make sure logical breakpoints map exists (#3115)
  * go.mod: update starlark dependency (#3112)
  * terminal: send large output to pager (#3060)
  * *: switch to int64 for goroutine IDs (#3110)
  * proc: use stdlib to compute CRC for gnu_debuglink section (#3105)
  * _scripts: fix CI on go1.19/linux/386 (#3100)
  * service/dap: Add support for empty string in substitutePath (#3088)
  * proc: fuse evalToplevelTypeCast and evalTypeCast (#3057)
  * _scripts: fix command to download Go version (#3099)
  * service/debugger: refactor state/collectBreakpointInfo for TargetGroup (#3064)
  * proc: do not panic reading bad G struct (#3098)
  * TeamCity,goversion: bump test matrix (#3092)
  * pkg/dwarf/line: Fix parsing file table for DWARFv5 (#3090)
  * :* Improve trace subcommand output (#3091)
  * Documentation: fix documentation of examinemem (#3087)
  * fix StepInstruction on 1 byte instruction with a software breackpoint (#3084)
  * pkg/proc/internal/ebpf: Fix handling of entry / return (#3081)
  * service/dap: fix indexing bug for maps (#3068)
  * pkg/proc/internal/ebpf: Fix size of ebpf type for fn_addr (#3080)
  * proc/native: refactor windows framework (#3079)
  * terminal/command: 'goroutines' command add new flags '-exec command' (#3044)
  * proc: support gnu_debuglink section (#3073)
  * pkg/locspec: support exact match in SubstitutePath (#3075)
  * proc/internal/ebpf: drop dependency on cgo (#3072)
  * cmd/dlv,proc: misc improvements to trace subcommand (#3069)
  * dwarf/op,proc: output register name when printing location exprs (#3052)
  * service/dap: limit disassembly range (#3045)
  * proc,service/debugger: introduce TargetGroup abstraction (#3030)
  * terminal: add ability to show disassembly instead of source (#3047)
  * terminal/command: add -per-g-hitcount option to condition command (#3055)
  * _scripts: un-pin mingw version (#3046)
* Mon Aug 22 2022 Dirk Müller <dmueller@suse.com>
- update list of excluded archs with those that raise
  your_operating_system_and_architecture_combination_is_not_supported_by_delve exception
* Wed Jul  6 2022 jkowalczyk@suse.com
- Update to version 1.9.0:
  * *: Bump version to 1.9.0 (#3054)
  * vendor: update version of go/packages to 0.1.11 (#3053)
  * proc: fix arm64SwitchStack for go1.19 (#3038)
  * dwarf/frame: discard indirect flag reading personality func in eh_frame (#3032)
  * proc/native: fix Ctrl-C handling on non-headless instances on windows (#3039)
  * proc: map access with string literal key should always succeed (#3036)
  * testcase: remove accidental debug binary (#3035)
  * *: run go1.19 'go fmt' on everything and fix problems (#3031)
  * proc/gdbserver: ignore spurious stop packet from debugserver (#3021)
  * service/test,proc: move variable evaluation test to pkg/proc (#3024)
  * proc: fix prettyprint for register components with large values (#3022)
  * go.mod: use pseudo verion for github.com/go-delve/liner (#3026)
  * pkg/proc: fix and improve freebsd register handling (#3019)
  * proc/native: fix Windows build (#3023)
  * proc,service: represent logical breakpoints explicitly (#2946)
  * dap: add MultiClientCloseServerMock and fix test shutdown leak (#3011)
  * pkg/terminal: Add auto-complete for local variables (#3004)
  * proc: fix fatal throw breakpoint on go1.19 (#3009)
  * dap: remote attach must not use terminateDebuggee in single-client launch mode (#2995)
  * proc/gdbserver: fix function call injection on rr (#3007)
  * proc: fix RFLAGS corruption after call injection on amd64 (#3002)
  * proc: fixes concerning call injection on freebsd and rr (#3000)
  * Documentation: document substitute-path more (#2998)
  * proc/core: return true for calls to Recorded (#2979)
  * proc: support function call injection on arm64 (#2996)
  * Documentation: add DAP launch/attach configuration matrix (#2991)
  * _scripts/test_linux.sh,_scripts/test_windows.ps1: always return exit code 0 when testing on tip (#2997)
  * proc: fix autogenerated helper skip on linux/386 PIE builds (#2975)
  * _scripts: always return exit code 0 when testing on tip (#2980)
  * proc: unlock OS thread on exit from handlePtraceFuncs (#2972)
  * service/debugger: close executable file (#2976)
  * proc: add support for setting additional registers on freebsd/amd64 (#2981)
  * service/debugger: make TestDebugger_LaunchWithTTY pass on FreeBSD (#2982)
* Sun Jun 26 2022 Berthold Gunreben <azouhr@opensuse.org>
- s390x is not in list of supported CPUs. Disable building for s390x.
* Wed May 18 2022 jkowalczyk@suse.com
- Initial package version 1.8.3:
  * Documentation: expand DAP launch/attach configurations section (#2977)
  * Documentation: Fix example block in cli README (#2974)
  * _scripts/make: do not exit if git SHA ID can not be retrieved (#2973)
  * proc: skip autogenerated functions correctly (#2959)
  * dlv dap: pass disable-aslr to backend (#2965)
  * gobuild: drop support for building on Go < 1.10 (#2960)
  * Documentation/api/dap/README: add dlv dap usage link (#2957)
  * CHANGELOG.md: fix date typos (#2956)
  * proc/gdbserial: shut down debuggee when failing to debug (#2953)
  * debugger: clarify no debug info errors (#2954)
  * dlv_test: fix TestChildProcessExitWhenNoDebugInfo to actually test strip binary (#2949)
  * proc: allow low index == len in reslice (#2951)
  * proc,service: pretty print time.Time variables (#2865)
  * *: fix some typos
  * Prefer locspec to linespec (#2941)
  * service/dap: support terminateDebuggee option for attach only (#2940)
  * proc: move resume notify and manual stop handling to Target (#2921)
  * proc/native/linux: replace uses of unix.Iovec for target addresses (#2922)
  * Documentation/api/dap/README: add release version links (#2923)
  * service-*: conform to godoc comments (#2916)
